#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-memocombinators
version:              0.5.1
visibility:           public
id:                   data-memocombinators-0.5.1-SZzvHGkbolAWPFM3aU4iA
key:                  data-memocombinators-0.5.1-SZzvHGkbolAWPFM3aU4iA
license:              BSD-3-Clause
maintainer:           lrpalmer@gmail.com
author:               Luke Palmer
stability:            experimental
homepage:             http://github.com/luqui/data-memocombinators
synopsis:             Combinators for building memo tables.
description:          Combinators for building memo tables.
category:             Data
abi:                  6524745bc1e748e07589fb19aa831af5
exposed:              True
exposed-modules:      Data.MemoCombinators Data.MemoCombinators.Class
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-memocombinators-0.5.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-memocombinators-0.5.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-memocombinators-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-memocombinators
hs-libraries:         HSdata-memocombinators-0.5.1-SZzvHGkbolAWPFM3aU4iA
depends:
    array-0.5.6.0 base-4.18.2.1
    data-inttrie-0.1.4-9KOlfoKOUKQFSHo9nFaLQ0

haddock-interfaces:
    /usr/share/doc/haskell-data-memocombinators/html/data-memocombinators.haddock

haddock-html:         /usr/share/doc/haskell-data-memocombinators/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

